@@ -9,23 +9,35 @@ from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
-MODEL_AIRQUALITYMONITOR_V1 = 'zhimi.airmonitor.v1'
-MODEL_AIRQUALITYMONITOR_B1 = 'cgllc.airmonitor.b1'
-MODEL_AIRQUALITYMONITOR_S1 = 'cgllc.airmonitor.s1'
+MODEL_AIRQUALITYMONITOR_V1 = "zhimi.airmonitor.v1"
+MODEL_AIRQUALITYMONITOR_B1 = "cgllc.airmonitor.b1"
+MODEL_AIRQUALITYMONITOR_S1 = "cgllc.airmonitor.s1"
 
 AVAILABLE_PROPERTIES_COMMON = [
-    'power', 'aqi', 'battery', 'usb_state', 'time_state',
-    'night_state', 'night_beg_time', 'night_end_time',
-    'sensor_state'
+    "power",
+    "aqi",
+    "battery",
+    "usb_state",
+    "time_state",
+    "night_state",
+    "night_beg_time",
+    "night_end_time",
+    "sensor_state",
 ]
 
-AVAILABLE_PROPERTIES_S1 = [
-    'battery', 'co2', 'humidity', 'pm25', 'temperature', 'tvoc'
+AVAILABLE_PROPERTIES_B1 = [
+    "co2e",
+    "humidity",
+    "pm25",
+    "temperature",
+    "tvoc"
 ]
 
+AVAILABLE_PROPERTIES_S1 = ["battery", "co2", "humidity", "pm25", "temperature", "tvoc"]
+
 AVAILABLE_PROPERTIES = {
     MODEL_AIRQUALITYMONITOR_V1: AVAILABLE_PROPERTIES_COMMON,
-    MODEL_AIRQUALITYMONITOR_B1: AVAILABLE_PROPERTIES_COMMON,
+    MODEL_AIRQUALITYMONITOR_B1: AVAILABLE_PROPERTIES_B1,
     MODEL_AIRQUALITYMONITOR_S1: AVAILABLE_PROPERTIES_S1,
 }
 
@@ -45,7 +57,8 @@ class AirQualityMonitorStatus:
 
         Response of a Xiaomi Air Quality Monitor (cgllc.airmonitor.b1):
 
-        unknown.
+        {'co2e': 1466, 'humidity': 59.79999923706055, 'pm25': 2, 'temperature': 19.799999237060547,
+         'temperature_unit': 'c', 'tvoc': 1.3948699235916138, 'tvoc_unit': 'mg_m3'}
 
         Response of a Xiaomi Air Quality Monitor (cgllc.airmonitor.s1):
 
@@ -57,9 +70,7 @@ class AirQualityMonitorStatus:
     @property
     def power(self) -> Optional[str]:
         """Current power state."""
-        if "power" in self.data and self.data["power"] is not None:
-            return self.data["power"]
-        return None
+        return self.data.get("power", None)
 
     @property
     def is_on(self) -> bool:
@@ -76,14 +87,12 @@ class AirQualityMonitorStatus:
     @property
     def aqi(self) -> Optional[int]:
         """Air quality index value. (0...600)."""
-        if "aqi" in self.data and self.data["aqi"] is not None:
-            return self.data["aqi"]
-        return None
+        return self.data.get("aqi", None)
 
     @property
-    def battery(self) -> int:
+    def battery(self) -> Optional[int]:
         """Current battery level (0...100)."""
-        return self.data["battery"]
+        return self.data.get("battery", None)
 
     @property
     def display_clock(self) -> Optional[bool]:
@@ -102,80 +111,75 @@ class AirQualityMonitorStatus:
     @property
     def night_time_begin(self) -> Optional[str]:
         """Return the begin of the night time."""
-        if "night_beg_time" in self.data and self.data["night_beg_time"] is not None:
-            return self.data["night_beg_time"]
-        return None
+        return self.data.get("night_beg_time", None)
 
     @property
     def night_time_end(self) -> Optional[str]:
         """Return the end of the night time."""
-        if "night_end_time" in self.data and self.data["night_end_time"] is not None:
-            return self.data["night_end_time"]
-        return None
+        return self.data.get("night_end_time", None)
 
     @property
     def sensor_state(self) -> Optional[str]:
         """Sensor state."""
-        if "sensor_state" in self.data and self.data["sensor_state"] is not None:
-            return self.data["sensor_state"]
-        return None
+        return self.data.get("sensor_state", None)
 
     @property
     def co2(self) -> Optional[int]:
-        """Return co2 value (400...9999)ppm for MODEL_AIRQUALITYMONITOR_S1."""
-        if "co2" in self.data and self.data["co2"] is not None:
-            return self.data["co2"]
-        return None
+        """Return co2 value (400...9999ppm)."""
+        return self.data.get("co2", None)
+
+    @property
+    def co2e(self) -> Optional[int]:
+        """Return co2e value (400...9999ppm)."""
+        return self.data.get("co2e", None)
 
     @property
     def humidity(self) -> Optional[float]:
-        """Return humidity value (0...100)% for MODEL_AIRQUALITYMONITOR_S1."""
-        if "humidity" in self.data and self.data["humidity"] is not None:
-            return self.data["humidity"]
-        return None
+        """Return humidity value (0...100%)."""
+        return self.data.get("humidity", None)
 
     @property
     def pm25(self) -> Optional[float]:
-        """Return pm2.5 value (0...999)μg/m³ for MODEL_AIRQUALITYMONITOR_S1."""
-        if "pm25" in self.data and self.data["pm25"] is not None:
-            return self.data["pm25"]
-        return None
+        """Return pm2.5 value (0...999μg/m³)."""
+        return self.data.get("pm25", None)
 
     @property
     def temperature(self) -> Optional[float]:
-        """Return temperature value (-10...50)°C for MODEL_AIRQUALITYMONITOR_S1."""
-        if "temperature" in self.data and self.data["temperature"] is not None:
-            return self.data["temperature"]
-        return None
+        """Return temperature value (-10...50°C)."""
+        return self.data.get("temperature", None)
 
     @property
     def tvoc(self) -> Optional[int]:
-        """Return tvoc value for MODEL_AIRQUALITYMONITOR_S1."""
-        if "tvoc" in self.data and self.data["tvoc"] is not None:
-            return self.data["tvoc"]
-        return None
+        """Return tvoc value."""
+        return self.data.get("tvoc", None)
 
     def __repr__(self) -> str:
-        s = "<AirQualityMonitorStatus power=%s, " \
-            "aqi=%s, " \
-            "battery=%s, " \
-            "usb_power=%s, " \
-            "temperature=%s, " \
-            "humidity=%s, " \
-            "co2=%s, " \
-            "pm2.5=%s, " \
-            "tvoc=%s, " \
-            "display_clock=%s>" % \
-            (self.power,
-             self.aqi,
-             self.battery,
-             self.usb_power,
-             self.temperature,
-             self.humidity,
-             self.co2,
-             self.pm25,
-             self.tvoc,
-             self.display_clock)
+        s = (
+            "<AirQualityMonitorStatus power=%s, "
+            "usb_power=%s, "
+            "battery=%s, "
+            "aqi=%s, "
+            "temperature=%s, "
+            "humidity=%s, "
+            "co2=%s, "
+            "co2e=%s, "
+            "pm2.5=%s, "
+            "tvoc=%s, "
+            "display_clock=%s>"
+            % (
+                self.power,
+                self.usb_power,
+                self.battery,
+                self.aqi,
+                self.temperature,
+                self.humidity,
+                self.co2,
+                self.co2e,
+                self.pm25,
+                self.tvoc,
+                self.display_clock,
+            )
+        )
         return s
 
     def __json__(self):
@@ -184,40 +188,57 @@ class AirQualityMonitorStatus:
 
 class AirQualityMonitor(Device):
     """Xiaomi PM2.5 Air Quality Monitor."""
-    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
-                 debug: int = 0, lazy_discover: bool = True,
-                 model: str = None) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
 
-        self.device_info = self.info()
-        if self.device_info and model is None:
-            model = self.device_info.model
+    def __init__(
+        self,
+        ip: str = None,
+        token: str = None,
+        start_id: int = 0,
+        debug: int = 0,
+        lazy_discover: bool = True,
+        model: str = MODEL_AIRQUALITYMONITOR_V1,
+    ) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover)
 
         if model in AVAILABLE_PROPERTIES:
             self.model = model
-        else:
+        elif model is not None:
             self.model = MODEL_AIRQUALITYMONITOR_V1
             _LOGGER.error("Device model %s unsupported. Falling back to %s.", model, self.model)
+        else:
+            """Force autodetection"""
+            self.model = None
 
     @command(
         default_output=format_output(
             "",
             "Power: {result.power}\n"
             "USB power: {result.usb_power}\n"
-            "AQI: {result.aqi}\n"
             "Battery: {result.battery}\n"
-            "Display clock: {result.display_clock}\n"
+            "AQI: {result.aqi}\n"
+            "Temperature: {result.temperature}\n"
+            "Humidity: {result.humidity}\n"
+            "CO2: {result.co2}\n"
+            "CO2e: {result.co2e}\n"
+            "PM2.5: {result.pm25}\n"
+            "TVOC: {result.tvoc}\n"
+            "Display clock: {result.display_clock}\n",
         )
     )
     def status(self) -> AirQualityMonitorStatus:
         """Return device status."""
 
+        if self.model is None:
+            """Autodetection"""
+            info = self.info()
+            self.model = info.model
+
         properties = AVAILABLE_PROPERTIES[self.model]
 
-        values = self.send(
-            "get_prop",
-            properties
-        )
+        if self.model == MODEL_AIRQUALITYMONITOR_B1:
+            values = self.send("get_air_data")
+        else:
+            values = self.send("get_prop", properties)
 
         properties_count = len(properties)
         values_count = len(values)
@@ -225,23 +246,23 @@ class AirQualityMonitor(Device):
             _LOGGER.debug(
                 "Count (%s) of requested properties does not match the "
                 "count (%s) of received values.",
-                properties_count, values_count)
+                properties_count,
+                values_count,
+            )
 
-        if self.model == MODEL_AIRQUALITYMONITOR_S1:
+        if self.model == MODEL_AIRQUALITYMONITOR_S1 or self.model == MODEL_AIRQUALITYMONITOR_B1:
             return AirQualityMonitorStatus(defaultdict(lambda: None, values))
         else:
-            return AirQualityMonitorStatus(defaultdict(lambda: None, zip(properties, values)))
+            return AirQualityMonitorStatus(
+                defaultdict(lambda: None, zip(properties, values))
+            )
 
-    @command(
-        default_output=format_output("Powering on"),
-    )
+    @command(default_output=format_output("Powering on"))
     def on(self):
         """Power on."""
         return self.send("set_power", ["on"])
 
-    @command(
-        default_output=format_output("Powering off"),
-    )
+    @command(default_output=format_output("Powering off"))
     def off(self):
         """Power off."""
         return self.send("set_power", ["off"])
@@ -250,8 +271,9 @@ class AirQualityMonitor(Device):
         click.argument("display_clock", type=bool),
         default_output=format_output(
             lambda led: "Turning on display clock"
-            if led else "Turning off display clock"
-        )
+            if led
+            else "Turning off display clock"
+        ),
     )
     def set_display_clock(self, display_clock: bool):
         """Enable/disable displaying a clock instead the AQI."""
@@ -263,9 +285,8 @@ class AirQualityMonitor(Device):
     @command(
         click.argument("auto_close", type=bool),
         default_output=format_output(
-            lambda led: "Turning on auto close"
-            if led else "Turning off auto close"
-        )
+            lambda led: "Turning on auto close" if led else "Turning off auto close"
+        ),
     )
     def set_auto_close(self, auto_close: bool):
         """Purpose unknown."""
@@ -277,9 +298,8 @@ class AirQualityMonitor(Device):
     @command(
         click.argument("night_mode", type=bool),
         default_output=format_output(
-            lambda led: "Turning on night mode"
-            if led else "Turning off night mode"
-        )
+            lambda led: "Turning on night mode" if led else "Turning off night mode"
+        ),
     )
     def set_night_mode(self, night_mode: bool):
         """Decrease the brightness of the display."""
@@ -294,10 +314,12 @@ class AirQualityMonitor(Device):
         click.argument("end_hour", type=int),
         click.argument("end_minute", type=int),
         default_output=format_output(
-            "Setting night time to {begin_hour}:{begin_minute} - {end_hour}:{end_minute}")
+            "Setting night time to {begin_hour}:{begin_minute} - {end_hour}:{end_minute}"
+        ),
     )
-    def set_night_time(self, begin_hour: int, begin_minute: int,
-                       end_hour: int, end_minute: int):
+    def set_night_time(
+        self, begin_hour: int, begin_minute: int, end_hour: int, end_minute: int
+    ):
         """Enable night mode daily at bedtime."""
         begin = begin_hour * 3600 + begin_minute * 60
         end = end_hour * 3600 + end_minute * 60
