@@ -9,10 +9,8 @@ from typing import Any, List, Optional  # noqa: F401
 import click
 import construct
 
-from .click_common import (
-    DeviceGroupMeta, command, format_output, LiteralParamType
-)
-from .exceptions import DeviceException, DeviceError
+from .click_common import DeviceGroupMeta, command, format_output, LiteralParamType
+from .exceptions import DeviceException, DeviceError, RecoverableError
 from .protocol import Message
 
 _LOGGER = logging.getLogger(__name__)
@@ -29,6 +27,7 @@ class DeviceInfo:
     """Container of miIO device information.
     Hardware properties such as device model, MAC address, memory information,
     and hardware and software information is contained here."""
+
     def __init__(self, data):
         """
         Response of a Xiaomi Smart WiFi Plug
@@ -58,7 +57,8 @@ class DeviceInfo:
             self.data["fw_ver"],
             self.data["mac"],
             self.network_interface["localIp"],
-            self.data["token"])
+            self.data["token"],
+        )
 
     def __json__(self):
         return self.data
@@ -113,8 +113,15 @@ class Device(metaclass=DeviceGroupMeta):
     the ``miIO`` protocol.
     This class should not be initialized directly but a device-specific class inheriting
     it should be used instead of it."""
-    def __init__(self, ip: str = None, token: str = None,
-                 start_id: int=0, debug: int=0, lazy_discover: bool=True) -> None:
+
+    def __init__(
+        self,
+        ip: str = None,
+        token: str = None,
+        start_id: int = 0,
+        debug: int = 0,
+        lazy_discover: bool = True,
+    ) -> None:
         """
         Create a :class:`Device` instance.
         :param ip: IP address or a hostname for the device
@@ -125,7 +132,7 @@ class Device(metaclass=DeviceGroupMeta):
         self.ip = ip
         self.port = 54321
         if token is None:
-            token = 32 * '0'
+            token = 32 * "0"
         if token is not None:
             self.token = bytes.fromhex(token)
         self.debug = debug
@@ -153,10 +160,12 @@ class Device(metaclass=DeviceGroupMeta):
             self._discovered = True
             if self.debug > 1:
                 _LOGGER.debug(m)
-            _LOGGER.debug("Discovered %s with ts: %s, token: %s",
-                          binascii.hexlify(self._device_id).decode(),
-                          self._device_ts,
-                          codecs.encode(m.checksum, 'hex'))
+            _LOGGER.debug(
+                "Discovered %s with ts: %s, token: %s",
+                binascii.hexlify(self._device_id).decode(),
+                self._device_ts,
+                codecs.encode(m.checksum, "hex"),
+            )
         else:
             _LOGGER.error("Unable to discover a device at address %s", self.ip)
             raise DeviceException("Unable to discover the device %s" % self.ip)
@@ -164,7 +173,7 @@ class Device(metaclass=DeviceGroupMeta):
         return m
 
     @staticmethod
-    def discover(addr: str=None) -> Any:
+    def discover(addr: str = None) -> Any:
         """Scan for devices in the network.
         This method is used to discover supported devices by sending a
         handshake message to the broadcast address on port 54321.
@@ -176,13 +185,13 @@ class Device(metaclass=DeviceGroupMeta):
         is_broadcast = addr is None
         seen_addrs = []  # type: List[str]
         if is_broadcast:
-            addr = '<broadcast>'
+            addr = "<broadcast>"
             is_broadcast = True
-            _LOGGER.info("Sending discovery to %s with timeout of %ss..",
-                         addr, timeout)
+            _LOGGER.info("Sending discovery to %s with timeout of %ss..", addr, timeout)
         # magic, length 32
         helobytes = bytes.fromhex(
-            '21310020ffffffffffffffffffffffffffffffffffffffffffffffffffffffff')
+            "21310020ffffffffffffffffffffffffffffffffffffffffffffffffffffffff"
+        )
 
         s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         s.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
@@ -197,10 +206,12 @@ class Device(metaclass=DeviceGroupMeta):
                     return m
 
                 if addr[0] not in seen_addrs:
-                    _LOGGER.info("  IP %s (ID: %s) - token: %s",
-                                 addr[0],
-                                 binascii.hexlify(m.header.value.device_id).decode(),
-                                 codecs.encode(m.checksum, 'hex'))
+                    _LOGGER.info(
+                        "  IP %s (ID: %s) - token: %s",
+                        addr[0],
+                        binascii.hexlify(m.header.value.device_id).decode(),
+                        codecs.encode(m.checksum, "hex"),
+                    )
                     seen_addrs.append(addr[0])
             except socket.timeout:
                 if is_broadcast:
@@ -210,7 +221,7 @@ class Device(metaclass=DeviceGroupMeta):
                 _LOGGER.warning("error while reading discover results: %s", ex)
                 break
 
-    def send(self, command: str, parameters: Any=None, retry_count=3) -> Any:
+    def send(self, command: str, parameters: Any = None, retry_count=3) -> Any:
         """Build and send the given command.
         Note that this will implicitly call :func:`do_discover` to do a handshake,
         and will re-try in case of errors while incrementing the `_id` by 100.
@@ -223,26 +234,30 @@ class Device(metaclass=DeviceGroupMeta):
         if not self.lazy_discover or not self._discovered:
             self.do_discover()
 
-        cmd = {
-            "id": self._id,
-            "method": command,
-        }
+        cmd = {"id": self._id, "method": command}
 
         if parameters is not None:
             cmd["params"] = parameters
+        else:
+            cmd["params"] = []
 
         send_ts = self._device_ts + datetime.timedelta(seconds=1)
-        header = {'length': 0, 'unknown': 0x00000000,
-                  'device_id': self._device_id, 'ts': send_ts}
+        header = {
+            "length": 0,
+            "unknown": 0x00000000,
+            "device_id": self._device_id,
+            "ts": send_ts,
+        }
 
-        msg = {'data': {'value': cmd},
-               'header': {'value': header},
-               'checksum': 0}
+        msg = {"data": {"value": cmd}, "header": {"value": header}, "checksum": 0}
         m = Message.build(msg, token=self.token)
         _LOGGER.debug("%s:%s >>: %s", self.ip, self.port, cmd)
         if self.debug > 1:
-            _LOGGER.debug("send (timeout %s): %s",
-                          self._timeout, Message.parse(m, token=self.token))
+            _LOGGER.debug(
+                "send (timeout %s): %s",
+                self._timeout,
+                Message.parse(m, token=self.token),
+            )
 
         s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         s.settimeout(self._timeout)
@@ -261,26 +276,35 @@ class Device(metaclass=DeviceGroupMeta):
                 _LOGGER.debug("recv from %s: %s", addr[0], m)
 
             self.__id = m.data.value["id"]
-            _LOGGER.debug("%s:%s (ts: %s, id: %s) << %s",
-                          self.ip, self.port,
-                          m.header.value.ts,
-                          m.data.value["id"],
-                          m.data.value)
+            _LOGGER.debug(
+                "%s:%s (ts: %s, id: %s) << %s",
+                self.ip,
+                self.port,
+                m.header.value.ts,
+                m.data.value["id"],
+                m.data.value,
+            )
             if "error" in m.data.value:
-                raise DeviceError(m.data.value["error"])
+                error = m.data.value["error"]
+                if "code" in error and error["code"] == -30001:
+                    raise RecoverableError(error)
+                raise DeviceError(error)
 
             try:
                 return m.data.value["result"]
             except KeyError:
                 return m.data.value
         except construct.core.ChecksumError as ex:
-            raise DeviceException("Got checksum error which indicates use "
-                                  "of an invalid token. "
-                                  "Please check your token!") from ex
+            raise DeviceException(
+                "Got checksum error which indicates use "
+                "of an invalid token. "
+                "Please check your token!"
+            ) from ex
         except OSError as ex:
             if retry_count > 0:
-                _LOGGER.debug("Retrying with incremented id, "
-                              "retries left: %s", retry_count)
+                _LOGGER.debug(
+                    "Retrying with incremented id, retries left: %s", retry_count
+                )
                 self.__id += 100
                 self._discovered = False
                 return self.send(command, parameters, retry_count - 1)
@@ -288,9 +312,19 @@ class Device(metaclass=DeviceGroupMeta):
             _LOGGER.error("Got error when receiving: %s", ex)
             raise DeviceException("No response from the device") from ex
 
+        except RecoverableError as ex:
+            if retry_count > 0:
+                _LOGGER.debug(
+                    "Retrying to send failed command, retries left: %s", retry_count
+                )
+                return self.send(command, parameters, retry_count - 1)
+
+            _LOGGER.error("Got error when receiving: %s", ex)
+            raise DeviceException("Unable to recover failed command") from ex
+
     @command(
-        click.argument('command', type=str, required=True),
-        click.argument('parameters', type=LiteralParamType(), required=False),
+        click.argument("command", type=str, required=True),
+        click.argument("parameters", type=LiteralParamType(), required=False),
     )
     def raw_command(self, command, parameters):
         """Send a raw command to the device.
@@ -308,13 +342,14 @@ class Device(metaclass=DeviceGroupMeta):
             "Hardware version: {result.hardware_version}\n"
             "Firmware version: {result.firmware_version}\n"
             "Network: {result.network_interface}\n"
-            "AP: {result.accesspoint}\n")
+            "AP: {result.accesspoint}\n",
+        )
     )
     def info(self) -> DeviceInfo:
         """Get miIO protocol information from the device.
         This includes information about connected wlan network,
         and harware and software versions."""
-        return DeviceInfo(self.send("miIO.info", []))
+        return DeviceInfo(self.send("miIO.info"))
 
     def update(self, url: str, md5: str):
         """Start an OTA update."""
@@ -323,24 +358,23 @@ class Device(metaclass=DeviceGroupMeta):
             "install": "1",
             "app_url": url,
             "file_md5": md5,
-            "proc": "dnld install"
+            "proc": "dnld install",
         }
         return self.send("miIO.ota", payload)[0] == "ok"
 
     def update_progress(self) -> int:
         """Return current update progress [0-100]."""
-        return self.send("miIO.get_ota_progress", [])[0]
+        return self.send("miIO.get_ota_progress")[0]
 
     def update_state(self):
         """Return current update state."""
-        return UpdateState(self.send("miIO.get_ota_state", [])[0])
+        return UpdateState(self.send("miIO.get_ota_state")[0])
 
     def configure_wifi(self, ssid, password, uid=0, extra_params=None):
         """Configure the wifi settings."""
         if extra_params is None:
             extra_params = {}
-        params = {"ssid": ssid, "passwd": password, "uid": uid,
-                  **extra_params}
+        params = {"ssid": ssid, "passwd": password, "uid": uid, **extra_params}
 
         return self.send("miIO.config_router", params)[0]
 
