@@ -7,17 +7,16 @@ from typing import Any  # noqa: F401
 import click
 
 import miio  # noqa: E402
-from miio.click_common import (ExceptionHandlerGroup, validate_ip,
-                               validate_token, )
+from miio.click_common import ExceptionHandlerGroup, validate_ip, validate_token
 
 _LOGGER = logging.getLogger(__name__)
 pass_dev = click.make_pass_decorator(miio.ChuangmiPlug)
 
 
 @click.group(invoke_without_command=True, cls=ExceptionHandlerGroup)
-@click.option('--ip', envvar="DEVICE_IP", callback=validate_ip)
-@click.option('--token', envvar="DEVICE_TOKEN", callback=validate_token)
-@click.option('-d', '--debug', default=False, count=True)
+@click.option("--ip", envvar="DEVICE_IP", callback=validate_ip)
+@click.option("--token", envvar="DEVICE_TOKEN", callback=validate_token)
+@click.option("-d", "--debug", default=False, count=True)
 @click.pass_context
 def cli(ctx, ip: str, token: str, debug: int):
     """A tool to command Xiaomi Smart Plug."""
@@ -77,8 +76,8 @@ def off(dev: miio.ChuangmiPlug):
 
 
 @cli.command()
-@click.argument('cmd', required=True)
-@click.argument('parameters', required=False)
+@click.argument("cmd", required=True)
+@click.argument("parameters", required=False)
 @pass_dev
 def raw_command(dev: miio.ChuangmiPlug, cmd, parameters):
     """Run a raw command."""
